# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ConversationNotificationParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ConversationNotificationParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'user_id': 'str',
            'external_contact_id': 'str',
            'external_organization_id': 'str',
            'name': 'str',
            'queue_id': 'str',
            'group_id': 'str',
            'purpose': 'str',
            'consult_participant_id': 'str',
            'address': 'str',
            'wrapup_required': 'bool',
            'wrapup_expected': 'bool',
            'wrapup_prompt': 'str',
            'wrapup_timeout_ms': 'int',
            'wrapup': 'ConversationNotificationWrapup',
            'monitored_participant_id': 'str',
            'attributes': 'dict(str, str)',
            'calls': 'list[ConversationNotificationCalls]',
            'callbacks': 'list[ConversationNotificationCallbacks]',
            'chats': 'list[ConversationNotificationChats]',
            'cobrowsesessions': 'list[ConversationNotificationCobrowsesessions]',
            'emails': 'list[ConversationNotificationEmails]',
            'screen_shares': 'list[ConversationNotificationScreenShares]',
            'social_expressions': 'list[ConversationNotificationSocialExpressions]',
            'videos': 'list[ConversationNotificationVideos]',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'user_id': 'userId',
            'external_contact_id': 'externalContactId',
            'external_organization_id': 'externalOrganizationId',
            'name': 'name',
            'queue_id': 'queueId',
            'group_id': 'groupId',
            'purpose': 'purpose',
            'consult_participant_id': 'consultParticipantId',
            'address': 'address',
            'wrapup_required': 'wrapupRequired',
            'wrapup_expected': 'wrapupExpected',
            'wrapup_prompt': 'wrapupPrompt',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup': 'wrapup',
            'monitored_participant_id': 'monitoredParticipantId',
            'attributes': 'attributes',
            'calls': 'calls',
            'callbacks': 'callbacks',
            'chats': 'chats',
            'cobrowsesessions': 'cobrowsesessions',
            'emails': 'emails',
            'screen_shares': 'screenShares',
            'social_expressions': 'socialExpressions',
            'videos': 'videos',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._connected_time = None
        self._end_time = None
        self._user_id = None
        self._external_contact_id = None
        self._external_organization_id = None
        self._name = None
        self._queue_id = None
        self._group_id = None
        self._purpose = None
        self._consult_participant_id = None
        self._address = None
        self._wrapup_required = None
        self._wrapup_expected = None
        self._wrapup_prompt = None
        self._wrapup_timeout_ms = None
        self._wrapup = None
        self._monitored_participant_id = None
        self._attributes = None
        self._calls = None
        self._callbacks = None
        self._chats = None
        self._cobrowsesessions = None
        self._emails = None
        self._screen_shares = None
        self._social_expressions = None
        self._videos = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this ConversationNotificationParticipant.


        :return: The id of this ConversationNotificationParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConversationNotificationParticipant.


        :param id: The id of this ConversationNotificationParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def connected_time(self):
        """
        Gets the connected_time of this ConversationNotificationParticipant.


        :return: The connected_time of this ConversationNotificationParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this ConversationNotificationParticipant.


        :param connected_time: The connected_time of this ConversationNotificationParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this ConversationNotificationParticipant.


        :return: The end_time of this ConversationNotificationParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this ConversationNotificationParticipant.


        :param end_time: The end_time of this ConversationNotificationParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def user_id(self):
        """
        Gets the user_id of this ConversationNotificationParticipant.


        :return: The user_id of this ConversationNotificationParticipant.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this ConversationNotificationParticipant.


        :param user_id: The user_id of this ConversationNotificationParticipant.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def external_contact_id(self):
        """
        Gets the external_contact_id of this ConversationNotificationParticipant.


        :return: The external_contact_id of this ConversationNotificationParticipant.
        :rtype: str
        """
        return self._external_contact_id

    @external_contact_id.setter
    def external_contact_id(self, external_contact_id):
        """
        Sets the external_contact_id of this ConversationNotificationParticipant.


        :param external_contact_id: The external_contact_id of this ConversationNotificationParticipant.
        :type: str
        """
        
        self._external_contact_id = external_contact_id

    @property
    def external_organization_id(self):
        """
        Gets the external_organization_id of this ConversationNotificationParticipant.


        :return: The external_organization_id of this ConversationNotificationParticipant.
        :rtype: str
        """
        return self._external_organization_id

    @external_organization_id.setter
    def external_organization_id(self, external_organization_id):
        """
        Sets the external_organization_id of this ConversationNotificationParticipant.


        :param external_organization_id: The external_organization_id of this ConversationNotificationParticipant.
        :type: str
        """
        
        self._external_organization_id = external_organization_id

    @property
    def name(self):
        """
        Gets the name of this ConversationNotificationParticipant.


        :return: The name of this ConversationNotificationParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConversationNotificationParticipant.


        :param name: The name of this ConversationNotificationParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def queue_id(self):
        """
        Gets the queue_id of this ConversationNotificationParticipant.


        :return: The queue_id of this ConversationNotificationParticipant.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this ConversationNotificationParticipant.


        :param queue_id: The queue_id of this ConversationNotificationParticipant.
        :type: str
        """
        
        self._queue_id = queue_id

    @property
    def group_id(self):
        """
        Gets the group_id of this ConversationNotificationParticipant.


        :return: The group_id of this ConversationNotificationParticipant.
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """
        Sets the group_id of this ConversationNotificationParticipant.


        :param group_id: The group_id of this ConversationNotificationParticipant.
        :type: str
        """
        
        self._group_id = group_id

    @property
    def purpose(self):
        """
        Gets the purpose of this ConversationNotificationParticipant.


        :return: The purpose of this ConversationNotificationParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this ConversationNotificationParticipant.


        :param purpose: The purpose of this ConversationNotificationParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def consult_participant_id(self):
        """
        Gets the consult_participant_id of this ConversationNotificationParticipant.


        :return: The consult_participant_id of this ConversationNotificationParticipant.
        :rtype: str
        """
        return self._consult_participant_id

    @consult_participant_id.setter
    def consult_participant_id(self, consult_participant_id):
        """
        Sets the consult_participant_id of this ConversationNotificationParticipant.


        :param consult_participant_id: The consult_participant_id of this ConversationNotificationParticipant.
        :type: str
        """
        
        self._consult_participant_id = consult_participant_id

    @property
    def address(self):
        """
        Gets the address of this ConversationNotificationParticipant.


        :return: The address of this ConversationNotificationParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this ConversationNotificationParticipant.


        :param address: The address of this ConversationNotificationParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this ConversationNotificationParticipant.


        :return: The wrapup_required of this ConversationNotificationParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this ConversationNotificationParticipant.


        :param wrapup_required: The wrapup_required of this ConversationNotificationParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_expected(self):
        """
        Gets the wrapup_expected of this ConversationNotificationParticipant.


        :return: The wrapup_expected of this ConversationNotificationParticipant.
        :rtype: bool
        """
        return self._wrapup_expected

    @wrapup_expected.setter
    def wrapup_expected(self, wrapup_expected):
        """
        Sets the wrapup_expected of this ConversationNotificationParticipant.


        :param wrapup_expected: The wrapup_expected of this ConversationNotificationParticipant.
        :type: bool
        """
        
        self._wrapup_expected = wrapup_expected

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this ConversationNotificationParticipant.


        :return: The wrapup_prompt of this ConversationNotificationParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this ConversationNotificationParticipant.


        :param wrapup_prompt: The wrapup_prompt of this ConversationNotificationParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this ConversationNotificationParticipant.


        :return: The wrapup_timeout_ms of this ConversationNotificationParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this ConversationNotificationParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this ConversationNotificationParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup(self):
        """
        Gets the wrapup of this ConversationNotificationParticipant.


        :return: The wrapup of this ConversationNotificationParticipant.
        :rtype: ConversationNotificationWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this ConversationNotificationParticipant.


        :param wrapup: The wrapup of this ConversationNotificationParticipant.
        :type: ConversationNotificationWrapup
        """
        
        self._wrapup = wrapup

    @property
    def monitored_participant_id(self):
        """
        Gets the monitored_participant_id of this ConversationNotificationParticipant.


        :return: The monitored_participant_id of this ConversationNotificationParticipant.
        :rtype: str
        """
        return self._monitored_participant_id

    @monitored_participant_id.setter
    def monitored_participant_id(self, monitored_participant_id):
        """
        Sets the monitored_participant_id of this ConversationNotificationParticipant.


        :param monitored_participant_id: The monitored_participant_id of this ConversationNotificationParticipant.
        :type: str
        """
        
        self._monitored_participant_id = monitored_participant_id

    @property
    def attributes(self):
        """
        Gets the attributes of this ConversationNotificationParticipant.


        :return: The attributes of this ConversationNotificationParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this ConversationNotificationParticipant.


        :param attributes: The attributes of this ConversationNotificationParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def calls(self):
        """
        Gets the calls of this ConversationNotificationParticipant.


        :return: The calls of this ConversationNotificationParticipant.
        :rtype: list[ConversationNotificationCalls]
        """
        return self._calls

    @calls.setter
    def calls(self, calls):
        """
        Sets the calls of this ConversationNotificationParticipant.


        :param calls: The calls of this ConversationNotificationParticipant.
        :type: list[ConversationNotificationCalls]
        """
        
        self._calls = calls

    @property
    def callbacks(self):
        """
        Gets the callbacks of this ConversationNotificationParticipant.


        :return: The callbacks of this ConversationNotificationParticipant.
        :rtype: list[ConversationNotificationCallbacks]
        """
        return self._callbacks

    @callbacks.setter
    def callbacks(self, callbacks):
        """
        Sets the callbacks of this ConversationNotificationParticipant.


        :param callbacks: The callbacks of this ConversationNotificationParticipant.
        :type: list[ConversationNotificationCallbacks]
        """
        
        self._callbacks = callbacks

    @property
    def chats(self):
        """
        Gets the chats of this ConversationNotificationParticipant.


        :return: The chats of this ConversationNotificationParticipant.
        :rtype: list[ConversationNotificationChats]
        """
        return self._chats

    @chats.setter
    def chats(self, chats):
        """
        Sets the chats of this ConversationNotificationParticipant.


        :param chats: The chats of this ConversationNotificationParticipant.
        :type: list[ConversationNotificationChats]
        """
        
        self._chats = chats

    @property
    def cobrowsesessions(self):
        """
        Gets the cobrowsesessions of this ConversationNotificationParticipant.


        :return: The cobrowsesessions of this ConversationNotificationParticipant.
        :rtype: list[ConversationNotificationCobrowsesessions]
        """
        return self._cobrowsesessions

    @cobrowsesessions.setter
    def cobrowsesessions(self, cobrowsesessions):
        """
        Sets the cobrowsesessions of this ConversationNotificationParticipant.


        :param cobrowsesessions: The cobrowsesessions of this ConversationNotificationParticipant.
        :type: list[ConversationNotificationCobrowsesessions]
        """
        
        self._cobrowsesessions = cobrowsesessions

    @property
    def emails(self):
        """
        Gets the emails of this ConversationNotificationParticipant.


        :return: The emails of this ConversationNotificationParticipant.
        :rtype: list[ConversationNotificationEmails]
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """
        Sets the emails of this ConversationNotificationParticipant.


        :param emails: The emails of this ConversationNotificationParticipant.
        :type: list[ConversationNotificationEmails]
        """
        
        self._emails = emails

    @property
    def screen_shares(self):
        """
        Gets the screen_shares of this ConversationNotificationParticipant.


        :return: The screen_shares of this ConversationNotificationParticipant.
        :rtype: list[ConversationNotificationScreenShares]
        """
        return self._screen_shares

    @screen_shares.setter
    def screen_shares(self, screen_shares):
        """
        Sets the screen_shares of this ConversationNotificationParticipant.


        :param screen_shares: The screen_shares of this ConversationNotificationParticipant.
        :type: list[ConversationNotificationScreenShares]
        """
        
        self._screen_shares = screen_shares

    @property
    def social_expressions(self):
        """
        Gets the social_expressions of this ConversationNotificationParticipant.


        :return: The social_expressions of this ConversationNotificationParticipant.
        :rtype: list[ConversationNotificationSocialExpressions]
        """
        return self._social_expressions

    @social_expressions.setter
    def social_expressions(self, social_expressions):
        """
        Sets the social_expressions of this ConversationNotificationParticipant.


        :param social_expressions: The social_expressions of this ConversationNotificationParticipant.
        :type: list[ConversationNotificationSocialExpressions]
        """
        
        self._social_expressions = social_expressions

    @property
    def videos(self):
        """
        Gets the videos of this ConversationNotificationParticipant.


        :return: The videos of this ConversationNotificationParticipant.
        :rtype: list[ConversationNotificationVideos]
        """
        return self._videos

    @videos.setter
    def videos(self, videos):
        """
        Sets the videos of this ConversationNotificationParticipant.


        :param videos: The videos of this ConversationNotificationParticipant.
        :type: list[ConversationNotificationVideos]
        """
        
        self._videos = videos

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this ConversationNotificationParticipant.


        :return: The additional_properties of this ConversationNotificationParticipant.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this ConversationNotificationParticipant.


        :param additional_properties: The additional_properties of this ConversationNotificationParticipant.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ConversationNotificationChat(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ConversationNotificationChat - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'id': 'str',
            'provider': 'str',
            'room_id': 'str',
            'held': 'bool',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'state': 'state',
            'id': 'id',
            'provider': 'provider',
            'room_id': 'roomId',
            'held': 'held',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'additional_properties': 'additionalProperties'
        }

        self._state = None
        self._id = None
        self._provider = None
        self._room_id = None
        self._held = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._additional_properties = None

    @property
    def state(self):
        """
        Gets the state of this ConversationNotificationChat.


        :return: The state of this ConversationNotificationChat.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ConversationNotificationChat.


        :param state: The state of this ConversationNotificationChat.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "NONE"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def id(self):
        """
        Gets the id of this ConversationNotificationChat.


        :return: The id of this ConversationNotificationChat.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConversationNotificationChat.


        :param id: The id of this ConversationNotificationChat.
        :type: str
        """
        
        self._id = id

    @property
    def provider(self):
        """
        Gets the provider of this ConversationNotificationChat.


        :return: The provider of this ConversationNotificationChat.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this ConversationNotificationChat.


        :param provider: The provider of this ConversationNotificationChat.
        :type: str
        """
        
        self._provider = provider

    @property
    def room_id(self):
        """
        Gets the room_id of this ConversationNotificationChat.


        :return: The room_id of this ConversationNotificationChat.
        :rtype: str
        """
        return self._room_id

    @room_id.setter
    def room_id(self, room_id):
        """
        Sets the room_id of this ConversationNotificationChat.


        :param room_id: The room_id of this ConversationNotificationChat.
        :type: str
        """
        
        self._room_id = room_id

    @property
    def held(self):
        """
        Gets the held of this ConversationNotificationChat.


        :return: The held of this ConversationNotificationChat.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this ConversationNotificationChat.


        :param held: The held of this ConversationNotificationChat.
        :type: bool
        """
        
        self._held = held

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this ConversationNotificationChat.


        :return: The disconnect_type of this ConversationNotificationChat.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this ConversationNotificationChat.


        :param disconnect_type: The disconnect_type of this ConversationNotificationChat.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSFER_FORWARD", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this ConversationNotificationChat.


        :return: The start_hold_time of this ConversationNotificationChat.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this ConversationNotificationChat.


        :param start_hold_time: The start_hold_time of this ConversationNotificationChat.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this ConversationNotificationChat.


        :return: The connected_time of this ConversationNotificationChat.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this ConversationNotificationChat.


        :param connected_time: The connected_time of this ConversationNotificationChat.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this ConversationNotificationChat.


        :return: The disconnected_time of this ConversationNotificationChat.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this ConversationNotificationChat.


        :param disconnected_time: The disconnected_time of this ConversationNotificationChat.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this ConversationNotificationChat.


        :return: The additional_properties of this ConversationNotificationChat.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this ConversationNotificationChat.


        :param additional_properties: The additional_properties of this ConversationNotificationChat.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class CallbackConversationNotificationCallbackMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CallbackConversationNotificationCallbackMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'CallbackConversationNotificationUser',
            'queue': 'CallbackConversationNotificationUriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'CallbackConversationNotificationErrorInfo',
            'script': 'CallbackConversationNotificationUriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'provider': 'str',
            'external_contact': 'CallbackConversationNotificationUriReference',
            'external_organization': 'CallbackConversationNotificationUriReference',
            'outbound_preview': 'ConversationNotificationDialerPreview',
            'callback_numbers': 'list[str]',
            'callback_user_name': 'str',
            'skip_enabled': 'bool',
            'timeout_seconds': 'int',
            'callback_scheduled_time': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'provider': 'provider',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'outbound_preview': 'outboundPreview',
            'callback_numbers': 'callbackNumbers',
            'callback_user_name': 'callbackUserName',
            'skip_enabled': 'skipEnabled',
            'timeout_seconds': 'timeoutSeconds',
            'callback_scheduled_time': 'callbackScheduledTime'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = None
        self._wrapup_required = None
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = None
        self._provider = None
        self._external_contact = None
        self._external_organization = None
        self._outbound_preview = None
        self._callback_numbers = None
        self._callback_user_name = None
        self._skip_enabled = None
        self._timeout_seconds = None
        self._callback_scheduled_time = None

    @property
    def id(self):
        """
        Gets the id of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The id of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CallbackConversationNotificationCallbackMediaParticipant.


        :param id: The id of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The name of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CallbackConversationNotificationCallbackMediaParticipant.


        :param name: The name of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The address of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this CallbackConversationNotificationCallbackMediaParticipant.


        :param address: The address of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The start_time of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this CallbackConversationNotificationCallbackMediaParticipant.


        :param start_time: The start_time of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The connected_time of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this CallbackConversationNotificationCallbackMediaParticipant.


        :param connected_time: The connected_time of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The end_time of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this CallbackConversationNotificationCallbackMediaParticipant.


        :param end_time: The end_time of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The start_hold_time of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this CallbackConversationNotificationCallbackMediaParticipant.


        :param start_hold_time: The start_hold_time of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The purpose of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this CallbackConversationNotificationCallbackMediaParticipant.


        :param purpose: The purpose of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The state of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this CallbackConversationNotificationCallbackMediaParticipant.


        :param state: The state of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "scheduled", "none"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The direction of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this CallbackConversationNotificationCallbackMediaParticipant.


        :param direction: The direction of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction not in allowed_values:
            raise ValueError(
                "Invalid value for `direction`, must be one of {0}"
                .format(allowed_values)
            )

        self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The disconnect_type of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this CallbackConversationNotificationCallbackMediaParticipant.


        :param disconnect_type: The disconnect_type of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "timeout", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The held of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this CallbackConversationNotificationCallbackMediaParticipant.


        :param held: The held of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The wrapup_required of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this CallbackConversationNotificationCallbackMediaParticipant.


        :param wrapup_required: The wrapup_required of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The wrapup_prompt of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this CallbackConversationNotificationCallbackMediaParticipant.


        :param wrapup_prompt: The wrapup_prompt of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The user of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: CallbackConversationNotificationUser
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this CallbackConversationNotificationCallbackMediaParticipant.


        :param user: The user of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: CallbackConversationNotificationUser
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The queue of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: CallbackConversationNotificationUriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this CallbackConversationNotificationCallbackMediaParticipant.


        :param queue: The queue of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: CallbackConversationNotificationUriReference
        """
        
        self._queue = queue

    @property
    def attributes(self):
        """
        Gets the attributes of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The attributes of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this CallbackConversationNotificationCallbackMediaParticipant.


        :param attributes: The attributes of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The error_info of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: CallbackConversationNotificationErrorInfo
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this CallbackConversationNotificationCallbackMediaParticipant.


        :param error_info: The error_info of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: CallbackConversationNotificationErrorInfo
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The script of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: CallbackConversationNotificationUriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this CallbackConversationNotificationCallbackMediaParticipant.


        :param script: The script of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: CallbackConversationNotificationUriReference
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The wrapup_timeout_ms of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this CallbackConversationNotificationCallbackMediaParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The wrapup_skipped of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this CallbackConversationNotificationCallbackMediaParticipant.


        :param wrapup_skipped: The wrapup_skipped of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def provider(self):
        """
        Gets the provider of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The provider of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this CallbackConversationNotificationCallbackMediaParticipant.


        :param provider: The provider of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: str
        """
        
        self._provider = provider

    @property
    def external_contact(self):
        """
        Gets the external_contact of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The external_contact of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: CallbackConversationNotificationUriReference
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this CallbackConversationNotificationCallbackMediaParticipant.


        :param external_contact: The external_contact of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: CallbackConversationNotificationUriReference
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The external_organization of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: CallbackConversationNotificationUriReference
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this CallbackConversationNotificationCallbackMediaParticipant.


        :param external_organization: The external_organization of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: CallbackConversationNotificationUriReference
        """
        
        self._external_organization = external_organization

    @property
    def outbound_preview(self):
        """
        Gets the outbound_preview of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The outbound_preview of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: ConversationNotificationDialerPreview
        """
        return self._outbound_preview

    @outbound_preview.setter
    def outbound_preview(self, outbound_preview):
        """
        Sets the outbound_preview of this CallbackConversationNotificationCallbackMediaParticipant.


        :param outbound_preview: The outbound_preview of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: ConversationNotificationDialerPreview
        """
        
        self._outbound_preview = outbound_preview

    @property
    def callback_numbers(self):
        """
        Gets the callback_numbers of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The callback_numbers of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: list[str]
        """
        return self._callback_numbers

    @callback_numbers.setter
    def callback_numbers(self, callback_numbers):
        """
        Sets the callback_numbers of this CallbackConversationNotificationCallbackMediaParticipant.


        :param callback_numbers: The callback_numbers of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: list[str]
        """
        
        self._callback_numbers = callback_numbers

    @property
    def callback_user_name(self):
        """
        Gets the callback_user_name of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The callback_user_name of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: str
        """
        return self._callback_user_name

    @callback_user_name.setter
    def callback_user_name(self, callback_user_name):
        """
        Sets the callback_user_name of this CallbackConversationNotificationCallbackMediaParticipant.


        :param callback_user_name: The callback_user_name of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: str
        """
        
        self._callback_user_name = callback_user_name

    @property
    def skip_enabled(self):
        """
        Gets the skip_enabled of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The skip_enabled of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: bool
        """
        return self._skip_enabled

    @skip_enabled.setter
    def skip_enabled(self, skip_enabled):
        """
        Sets the skip_enabled of this CallbackConversationNotificationCallbackMediaParticipant.


        :param skip_enabled: The skip_enabled of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: bool
        """
        
        self._skip_enabled = skip_enabled

    @property
    def timeout_seconds(self):
        """
        Gets the timeout_seconds of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The timeout_seconds of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: int
        """
        return self._timeout_seconds

    @timeout_seconds.setter
    def timeout_seconds(self, timeout_seconds):
        """
        Sets the timeout_seconds of this CallbackConversationNotificationCallbackMediaParticipant.


        :param timeout_seconds: The timeout_seconds of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: int
        """
        
        self._timeout_seconds = timeout_seconds

    @property
    def callback_scheduled_time(self):
        """
        Gets the callback_scheduled_time of this CallbackConversationNotificationCallbackMediaParticipant.


        :return: The callback_scheduled_time of this CallbackConversationNotificationCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._callback_scheduled_time

    @callback_scheduled_time.setter
    def callback_scheduled_time(self, callback_scheduled_time):
        """
        Sets the callback_scheduled_time of this CallbackConversationNotificationCallbackMediaParticipant.


        :param callback_scheduled_time: The callback_scheduled_time of this CallbackConversationNotificationCallbackMediaParticipant.
        :type: datetime
        """
        
        self._callback_scheduled_time = callback_scheduled_time

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Address(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Address - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'name_raw': 'str',
            'address_normalized': 'str',
            'address_raw': 'str',
            'address_displayable': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'name_raw': 'nameRaw',
            'address_normalized': 'addressNormalized',
            'address_raw': 'addressRaw',
            'address_displayable': 'addressDisplayable'
        }

        self._name = None
        self._name_raw = None
        self._address_normalized = None
        self._address_raw = None
        self._address_displayable = None

    @property
    def name(self):
        """
        Gets the name of this Address.
        This will be nameRaw if present, or a locality lookup of the address field otherwise.

        :return: The name of this Address.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Address.
        This will be nameRaw if present, or a locality lookup of the address field otherwise.

        :param name: The name of this Address.
        :type: str
        """
        
        self._name = name

    @property
    def name_raw(self):
        """
        Gets the name_raw of this Address.
        The name as close to the bits on the wire as possible.

        :return: The name_raw of this Address.
        :rtype: str
        """
        return self._name_raw

    @name_raw.setter
    def name_raw(self, name_raw):
        """
        Sets the name_raw of this Address.
        The name as close to the bits on the wire as possible.

        :param name_raw: The name_raw of this Address.
        :type: str
        """
        
        self._name_raw = name_raw

    @property
    def address_normalized(self):
        """
        Gets the address_normalized of this Address.
        The normalized address. This field is acquired from the Address Normalization Table.  The addressRaw could have gone through some transformations, such as only using the numeric portion, before being run through the Address Normalization Table.

        :return: The address_normalized of this Address.
        :rtype: str
        """
        return self._address_normalized

    @address_normalized.setter
    def address_normalized(self, address_normalized):
        """
        Sets the address_normalized of this Address.
        The normalized address. This field is acquired from the Address Normalization Table.  The addressRaw could have gone through some transformations, such as only using the numeric portion, before being run through the Address Normalization Table.

        :param address_normalized: The address_normalized of this Address.
        :type: str
        """
        
        self._address_normalized = address_normalized

    @property
    def address_raw(self):
        """
        Gets the address_raw of this Address.
        The address as close to the bits on the wire as possible.

        :return: The address_raw of this Address.
        :rtype: str
        """
        return self._address_raw

    @address_raw.setter
    def address_raw(self, address_raw):
        """
        Sets the address_raw of this Address.
        The address as close to the bits on the wire as possible.

        :param address_raw: The address_raw of this Address.
        :type: str
        """
        
        self._address_raw = address_raw

    @property
    def address_displayable(self):
        """
        Gets the address_displayable of this Address.
        The displayable address. This field is acquired from the Address Normalization Table.  The addressRaw could have gone through some transformations, such as only using the numeric portion, before being run through the Address Normalization Table.

        :return: The address_displayable of this Address.
        :rtype: str
        """
        return self._address_displayable

    @address_displayable.setter
    def address_displayable(self, address_displayable):
        """
        Sets the address_displayable of this Address.
        The displayable address. This field is acquired from the Address Normalization Table.  The addressRaw could have gone through some transformations, such as only using the numeric portion, before being run through the Address Normalization Table.

        :param address_displayable: The address_displayable of this Address.
        :type: str
        """
        
        self._address_displayable = address_displayable

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class DomainCapabilities(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DomainCapabilities - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'enabled': 'bool',
            'dhcp': 'bool',
            'metric': 'int',
            'auto_metric': 'bool',
            'supports_metric': 'bool'
        }

        self.attribute_map = {
            'enabled': 'enabled',
            'dhcp': 'dhcp',
            'metric': 'metric',
            'auto_metric': 'autoMetric',
            'supports_metric': 'supportsMetric'
        }

        self._enabled = False
        self._dhcp = False
        self._metric = None
        self._auto_metric = False
        self._supports_metric = False

    @property
    def enabled(self):
        """
        Gets the enabled of this DomainCapabilities.
        True if this address family on the interface is enabled.

        :return: The enabled of this DomainCapabilities.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this DomainCapabilities.
        True if this address family on the interface is enabled.

        :param enabled: The enabled of this DomainCapabilities.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def dhcp(self):
        """
        Gets the dhcp of this DomainCapabilities.
        True if this address family on the interface is using DHCP.

        :return: The dhcp of this DomainCapabilities.
        :rtype: bool
        """
        return self._dhcp

    @dhcp.setter
    def dhcp(self, dhcp):
        """
        Sets the dhcp of this DomainCapabilities.
        True if this address family on the interface is using DHCP.

        :param dhcp: The dhcp of this DomainCapabilities.
        :type: bool
        """
        
        self._dhcp = dhcp

    @property
    def metric(self):
        """
        Gets the metric of this DomainCapabilities.
        The metric being used for the address family on this interface. Lower values will have a higher priority. If autoMetric is true, this value will be the automatically calculated metric. To set this value be sure autoMetric is false. If no value is returned, metric configuration is not supported on this Edge.

        :return: The metric of this DomainCapabilities.
        :rtype: int
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this DomainCapabilities.
        The metric being used for the address family on this interface. Lower values will have a higher priority. If autoMetric is true, this value will be the automatically calculated metric. To set this value be sure autoMetric is false. If no value is returned, metric configuration is not supported on this Edge.

        :param metric: The metric of this DomainCapabilities.
        :type: int
        """
        
        self._metric = metric

    @property
    def auto_metric(self):
        """
        Gets the auto_metric of this DomainCapabilities.
        True if the metric is being calculated automatically for the address family on this interface.

        :return: The auto_metric of this DomainCapabilities.
        :rtype: bool
        """
        return self._auto_metric

    @auto_metric.setter
    def auto_metric(self, auto_metric):
        """
        Sets the auto_metric of this DomainCapabilities.
        True if the metric is being calculated automatically for the address family on this interface.

        :param auto_metric: The auto_metric of this DomainCapabilities.
        :type: bool
        """
        
        self._auto_metric = auto_metric

    @property
    def supports_metric(self):
        """
        Gets the supports_metric of this DomainCapabilities.
        True if metric configuration is supported.

        :return: The supports_metric of this DomainCapabilities.
        :rtype: bool
        """
        return self._supports_metric

    @supports_metric.setter
    def supports_metric(self, supports_metric):
        """
        Sets the supports_metric of this DomainCapabilities.
        True if metric configuration is supported.

        :param supports_metric: The supports_metric of this DomainCapabilities.
        :type: bool
        """
        
        self._supports_metric = supports_metric

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ChatConversationNotificationChatMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ChatConversationNotificationChatMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'CallbackConversationNotificationUser',
            'queue': 'ChatConversationNotificationUriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'ChatConversationNotificationErrorInfo',
            'script': 'ChatConversationNotificationUriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'provider': 'str',
            'external_contact': 'ChatConversationNotificationUriReference',
            'external_organization': 'ChatConversationNotificationUriReference',
            'room_id': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'provider': 'provider',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'room_id': 'roomId'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = None
        self._wrapup_required = None
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = None
        self._provider = None
        self._external_contact = None
        self._external_organization = None
        self._room_id = None

    @property
    def id(self):
        """
        Gets the id of this ChatConversationNotificationChatMediaParticipant.


        :return: The id of this ChatConversationNotificationChatMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ChatConversationNotificationChatMediaParticipant.


        :param id: The id of this ChatConversationNotificationChatMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ChatConversationNotificationChatMediaParticipant.


        :return: The name of this ChatConversationNotificationChatMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ChatConversationNotificationChatMediaParticipant.


        :param name: The name of this ChatConversationNotificationChatMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this ChatConversationNotificationChatMediaParticipant.


        :return: The address of this ChatConversationNotificationChatMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this ChatConversationNotificationChatMediaParticipant.


        :param address: The address of this ChatConversationNotificationChatMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this ChatConversationNotificationChatMediaParticipant.


        :return: The start_time of this ChatConversationNotificationChatMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this ChatConversationNotificationChatMediaParticipant.


        :param start_time: The start_time of this ChatConversationNotificationChatMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this ChatConversationNotificationChatMediaParticipant.


        :return: The connected_time of this ChatConversationNotificationChatMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this ChatConversationNotificationChatMediaParticipant.


        :param connected_time: The connected_time of this ChatConversationNotificationChatMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this ChatConversationNotificationChatMediaParticipant.


        :return: The end_time of this ChatConversationNotificationChatMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this ChatConversationNotificationChatMediaParticipant.


        :param end_time: The end_time of this ChatConversationNotificationChatMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this ChatConversationNotificationChatMediaParticipant.


        :return: The start_hold_time of this ChatConversationNotificationChatMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this ChatConversationNotificationChatMediaParticipant.


        :param start_hold_time: The start_hold_time of this ChatConversationNotificationChatMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this ChatConversationNotificationChatMediaParticipant.


        :return: The purpose of this ChatConversationNotificationChatMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this ChatConversationNotificationChatMediaParticipant.


        :param purpose: The purpose of this ChatConversationNotificationChatMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this ChatConversationNotificationChatMediaParticipant.


        :return: The state of this ChatConversationNotificationChatMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ChatConversationNotificationChatMediaParticipant.


        :param state: The state of this ChatConversationNotificationChatMediaParticipant.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "scheduled", "none"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this ChatConversationNotificationChatMediaParticipant.


        :return: The direction of this ChatConversationNotificationChatMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this ChatConversationNotificationChatMediaParticipant.


        :param direction: The direction of this ChatConversationNotificationChatMediaParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction not in allowed_values:
            raise ValueError(
                "Invalid value for `direction`, must be one of {0}"
                .format(allowed_values)
            )

        self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this ChatConversationNotificationChatMediaParticipant.


        :return: The disconnect_type of this ChatConversationNotificationChatMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this ChatConversationNotificationChatMediaParticipant.


        :param disconnect_type: The disconnect_type of this ChatConversationNotificationChatMediaParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "timeout", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this ChatConversationNotificationChatMediaParticipant.


        :return: The held of this ChatConversationNotificationChatMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this ChatConversationNotificationChatMediaParticipant.


        :param held: The held of this ChatConversationNotificationChatMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this ChatConversationNotificationChatMediaParticipant.


        :return: The wrapup_required of this ChatConversationNotificationChatMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this ChatConversationNotificationChatMediaParticipant.


        :param wrapup_required: The wrapup_required of this ChatConversationNotificationChatMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this ChatConversationNotificationChatMediaParticipant.


        :return: The wrapup_prompt of this ChatConversationNotificationChatMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this ChatConversationNotificationChatMediaParticipant.


        :param wrapup_prompt: The wrapup_prompt of this ChatConversationNotificationChatMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this ChatConversationNotificationChatMediaParticipant.


        :return: The user of this ChatConversationNotificationChatMediaParticipant.
        :rtype: CallbackConversationNotificationUser
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this ChatConversationNotificationChatMediaParticipant.


        :param user: The user of this ChatConversationNotificationChatMediaParticipant.
        :type: CallbackConversationNotificationUser
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this ChatConversationNotificationChatMediaParticipant.


        :return: The queue of this ChatConversationNotificationChatMediaParticipant.
        :rtype: ChatConversationNotificationUriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this ChatConversationNotificationChatMediaParticipant.


        :param queue: The queue of this ChatConversationNotificationChatMediaParticipant.
        :type: ChatConversationNotificationUriReference
        """
        
        self._queue = queue

    @property
    def attributes(self):
        """
        Gets the attributes of this ChatConversationNotificationChatMediaParticipant.


        :return: The attributes of this ChatConversationNotificationChatMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this ChatConversationNotificationChatMediaParticipant.


        :param attributes: The attributes of this ChatConversationNotificationChatMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this ChatConversationNotificationChatMediaParticipant.


        :return: The error_info of this ChatConversationNotificationChatMediaParticipant.
        :rtype: ChatConversationNotificationErrorInfo
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this ChatConversationNotificationChatMediaParticipant.


        :param error_info: The error_info of this ChatConversationNotificationChatMediaParticipant.
        :type: ChatConversationNotificationErrorInfo
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this ChatConversationNotificationChatMediaParticipant.


        :return: The script of this ChatConversationNotificationChatMediaParticipant.
        :rtype: ChatConversationNotificationUriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this ChatConversationNotificationChatMediaParticipant.


        :param script: The script of this ChatConversationNotificationChatMediaParticipant.
        :type: ChatConversationNotificationUriReference
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this ChatConversationNotificationChatMediaParticipant.


        :return: The wrapup_timeout_ms of this ChatConversationNotificationChatMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this ChatConversationNotificationChatMediaParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this ChatConversationNotificationChatMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this ChatConversationNotificationChatMediaParticipant.


        :return: The wrapup_skipped of this ChatConversationNotificationChatMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this ChatConversationNotificationChatMediaParticipant.


        :param wrapup_skipped: The wrapup_skipped of this ChatConversationNotificationChatMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def provider(self):
        """
        Gets the provider of this ChatConversationNotificationChatMediaParticipant.


        :return: The provider of this ChatConversationNotificationChatMediaParticipant.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this ChatConversationNotificationChatMediaParticipant.


        :param provider: The provider of this ChatConversationNotificationChatMediaParticipant.
        :type: str
        """
        
        self._provider = provider

    @property
    def external_contact(self):
        """
        Gets the external_contact of this ChatConversationNotificationChatMediaParticipant.


        :return: The external_contact of this ChatConversationNotificationChatMediaParticipant.
        :rtype: ChatConversationNotificationUriReference
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this ChatConversationNotificationChatMediaParticipant.


        :param external_contact: The external_contact of this ChatConversationNotificationChatMediaParticipant.
        :type: ChatConversationNotificationUriReference
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this ChatConversationNotificationChatMediaParticipant.


        :return: The external_organization of this ChatConversationNotificationChatMediaParticipant.
        :rtype: ChatConversationNotificationUriReference
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this ChatConversationNotificationChatMediaParticipant.


        :param external_organization: The external_organization of this ChatConversationNotificationChatMediaParticipant.
        :type: ChatConversationNotificationUriReference
        """
        
        self._external_organization = external_organization

    @property
    def room_id(self):
        """
        Gets the room_id of this ChatConversationNotificationChatMediaParticipant.


        :return: The room_id of this ChatConversationNotificationChatMediaParticipant.
        :rtype: str
        """
        return self._room_id

    @room_id.setter
    def room_id(self, room_id):
        """
        Sets the room_id of this ChatConversationNotificationChatMediaParticipant.


        :param room_id: The room_id of this ChatConversationNotificationChatMediaParticipant.
        :type: str
        """
        
        self._room_id = room_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class CampaignInteraction(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CampaignInteraction - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'campaign': 'UriReference',
            'agent': 'UriReference',
            'contact': 'UriReference',
            'destination_address': 'str',
            'active_preview_call': 'bool',
            'last_active_preview_wrapup_time': 'datetime',
            'creation_time': 'datetime',
            'call_placed_time': 'datetime',
            'call_routed_time': 'datetime',
            'preview_connected_time': 'datetime',
            'queue': 'UriReference',
            'script': 'UriReference',
            'disposition': 'str',
            'caller_name': 'str',
            'caller_address': 'str',
            'preview_pop_delivered_time': 'datetime',
            'conversation': 'Conversation',
            'dialer_system_participant_id': 'str',
            'dialing_mode': 'str',
            'skills': 'list[UriReference]'
        }

        self.attribute_map = {
            'id': 'id',
            'campaign': 'campaign',
            'agent': 'agent',
            'contact': 'contact',
            'destination_address': 'destinationAddress',
            'active_preview_call': 'activePreviewCall',
            'last_active_preview_wrapup_time': 'lastActivePreviewWrapupTime',
            'creation_time': 'creationTime',
            'call_placed_time': 'callPlacedTime',
            'call_routed_time': 'callRoutedTime',
            'preview_connected_time': 'previewConnectedTime',
            'queue': 'queue',
            'script': 'script',
            'disposition': 'disposition',
            'caller_name': 'callerName',
            'caller_address': 'callerAddress',
            'preview_pop_delivered_time': 'previewPopDeliveredTime',
            'conversation': 'conversation',
            'dialer_system_participant_id': 'dialerSystemParticipantId',
            'dialing_mode': 'dialingMode',
            'skills': 'skills'
        }

        self._id = None
        self._campaign = None
        self._agent = None
        self._contact = None
        self._destination_address = None
        self._active_preview_call = False
        self._last_active_preview_wrapup_time = None
        self._creation_time = None
        self._call_placed_time = None
        self._call_routed_time = None
        self._preview_connected_time = None
        self._queue = None
        self._script = None
        self._disposition = None
        self._caller_name = None
        self._caller_address = None
        self._preview_pop_delivered_time = None
        self._conversation = None
        self._dialer_system_participant_id = None
        self._dialing_mode = None
        self._skills = None

    @property
    def id(self):
        """
        Gets the id of this CampaignInteraction.


        :return: The id of this CampaignInteraction.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CampaignInteraction.


        :param id: The id of this CampaignInteraction.
        :type: str
        """
        
        self._id = id

    @property
    def campaign(self):
        """
        Gets the campaign of this CampaignInteraction.


        :return: The campaign of this CampaignInteraction.
        :rtype: UriReference
        """
        return self._campaign

    @campaign.setter
    def campaign(self, campaign):
        """
        Sets the campaign of this CampaignInteraction.


        :param campaign: The campaign of this CampaignInteraction.
        :type: UriReference
        """
        
        self._campaign = campaign

    @property
    def agent(self):
        """
        Gets the agent of this CampaignInteraction.


        :return: The agent of this CampaignInteraction.
        :rtype: UriReference
        """
        return self._agent

    @agent.setter
    def agent(self, agent):
        """
        Sets the agent of this CampaignInteraction.


        :param agent: The agent of this CampaignInteraction.
        :type: UriReference
        """
        
        self._agent = agent

    @property
    def contact(self):
        """
        Gets the contact of this CampaignInteraction.


        :return: The contact of this CampaignInteraction.
        :rtype: UriReference
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """
        Sets the contact of this CampaignInteraction.


        :param contact: The contact of this CampaignInteraction.
        :type: UriReference
        """
        
        self._contact = contact

    @property
    def destination_address(self):
        """
        Gets the destination_address of this CampaignInteraction.


        :return: The destination_address of this CampaignInteraction.
        :rtype: str
        """
        return self._destination_address

    @destination_address.setter
    def destination_address(self, destination_address):
        """
        Sets the destination_address of this CampaignInteraction.


        :param destination_address: The destination_address of this CampaignInteraction.
        :type: str
        """
        
        self._destination_address = destination_address

    @property
    def active_preview_call(self):
        """
        Gets the active_preview_call of this CampaignInteraction.
        Boolean value if there is an active preview call on the interaction

        :return: The active_preview_call of this CampaignInteraction.
        :rtype: bool
        """
        return self._active_preview_call

    @active_preview_call.setter
    def active_preview_call(self, active_preview_call):
        """
        Sets the active_preview_call of this CampaignInteraction.
        Boolean value if there is an active preview call on the interaction

        :param active_preview_call: The active_preview_call of this CampaignInteraction.
        :type: bool
        """
        
        self._active_preview_call = active_preview_call

    @property
    def last_active_preview_wrapup_time(self):
        """
        Gets the last_active_preview_wrapup_time of this CampaignInteraction.
        The time when the last preview of the interaction was wrapped up. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The last_active_preview_wrapup_time of this CampaignInteraction.
        :rtype: datetime
        """
        return self._last_active_preview_wrapup_time

    @last_active_preview_wrapup_time.setter
    def last_active_preview_wrapup_time(self, last_active_preview_wrapup_time):
        """
        Sets the last_active_preview_wrapup_time of this CampaignInteraction.
        The time when the last preview of the interaction was wrapped up. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param last_active_preview_wrapup_time: The last_active_preview_wrapup_time of this CampaignInteraction.
        :type: datetime
        """
        
        self._last_active_preview_wrapup_time = last_active_preview_wrapup_time

    @property
    def creation_time(self):
        """
        Gets the creation_time of this CampaignInteraction.
        The time when dialer created the interaction. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The creation_time of this CampaignInteraction.
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """
        Sets the creation_time of this CampaignInteraction.
        The time when dialer created the interaction. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param creation_time: The creation_time of this CampaignInteraction.
        :type: datetime
        """
        
        self._creation_time = creation_time

    @property
    def call_placed_time(self):
        """
        Gets the call_placed_time of this CampaignInteraction.
        The time when the agent or system places the call. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The call_placed_time of this CampaignInteraction.
        :rtype: datetime
        """
        return self._call_placed_time

    @call_placed_time.setter
    def call_placed_time(self, call_placed_time):
        """
        Sets the call_placed_time of this CampaignInteraction.
        The time when the agent or system places the call. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param call_placed_time: The call_placed_time of this CampaignInteraction.
        :type: datetime
        """
        
        self._call_placed_time = call_placed_time

    @property
    def call_routed_time(self):
        """
        Gets the call_routed_time of this CampaignInteraction.
        The time when the agent was connected to the call. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The call_routed_time of this CampaignInteraction.
        :rtype: datetime
        """
        return self._call_routed_time

    @call_routed_time.setter
    def call_routed_time(self, call_routed_time):
        """
        Sets the call_routed_time of this CampaignInteraction.
        The time when the agent was connected to the call. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param call_routed_time: The call_routed_time of this CampaignInteraction.
        :type: datetime
        """
        
        self._call_routed_time = call_routed_time

    @property
    def preview_connected_time(self):
        """
        Gets the preview_connected_time of this CampaignInteraction.
        The time when the customer and routing participant are connected. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The preview_connected_time of this CampaignInteraction.
        :rtype: datetime
        """
        return self._preview_connected_time

    @preview_connected_time.setter
    def preview_connected_time(self, preview_connected_time):
        """
        Sets the preview_connected_time of this CampaignInteraction.
        The time when the customer and routing participant are connected. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param preview_connected_time: The preview_connected_time of this CampaignInteraction.
        :type: datetime
        """
        
        self._preview_connected_time = preview_connected_time

    @property
    def queue(self):
        """
        Gets the queue of this CampaignInteraction.


        :return: The queue of this CampaignInteraction.
        :rtype: UriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this CampaignInteraction.


        :param queue: The queue of this CampaignInteraction.
        :type: UriReference
        """
        
        self._queue = queue

    @property
    def script(self):
        """
        Gets the script of this CampaignInteraction.


        :return: The script of this CampaignInteraction.
        :rtype: UriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this CampaignInteraction.


        :param script: The script of this CampaignInteraction.
        :type: UriReference
        """
        
        self._script = script

    @property
    def disposition(self):
        """
        Gets the disposition of this CampaignInteraction.
        Describes what happened with call analysis for instance: disposition.classification.callable.person, disposition.classification.callable.noanswer

        :return: The disposition of this CampaignInteraction.
        :rtype: str
        """
        return self._disposition

    @disposition.setter
    def disposition(self, disposition):
        """
        Sets the disposition of this CampaignInteraction.
        Describes what happened with call analysis for instance: disposition.classification.callable.person, disposition.classification.callable.noanswer

        :param disposition: The disposition of this CampaignInteraction.
        :type: str
        """
        allowed_values = ["DISCONNECT", "LIVE_VOICE", "BUSY", "MACHINE", "NO_ANSWER", "SIT_CALLABLE", "SIT_UNCALLABLE", "FAX"]
        if disposition not in allowed_values:
            raise ValueError(
                "Invalid value for `disposition`, must be one of {0}"
                .format(allowed_values)
            )

        self._disposition = disposition

    @property
    def caller_name(self):
        """
        Gets the caller_name of this CampaignInteraction.


        :return: The caller_name of this CampaignInteraction.
        :rtype: str
        """
        return self._caller_name

    @caller_name.setter
    def caller_name(self, caller_name):
        """
        Sets the caller_name of this CampaignInteraction.


        :param caller_name: The caller_name of this CampaignInteraction.
        :type: str
        """
        
        self._caller_name = caller_name

    @property
    def caller_address(self):
        """
        Gets the caller_address of this CampaignInteraction.


        :return: The caller_address of this CampaignInteraction.
        :rtype: str
        """
        return self._caller_address

    @caller_address.setter
    def caller_address(self, caller_address):
        """
        Sets the caller_address of this CampaignInteraction.


        :param caller_address: The caller_address of this CampaignInteraction.
        :type: str
        """
        
        self._caller_address = caller_address

    @property
    def preview_pop_delivered_time(self):
        """
        Gets the preview_pop_delivered_time of this CampaignInteraction.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The preview_pop_delivered_time of this CampaignInteraction.
        :rtype: datetime
        """
        return self._preview_pop_delivered_time

    @preview_pop_delivered_time.setter
    def preview_pop_delivered_time(self, preview_pop_delivered_time):
        """
        Sets the preview_pop_delivered_time of this CampaignInteraction.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param preview_pop_delivered_time: The preview_pop_delivered_time of this CampaignInteraction.
        :type: datetime
        """
        
        self._preview_pop_delivered_time = preview_pop_delivered_time

    @property
    def conversation(self):
        """
        Gets the conversation of this CampaignInteraction.


        :return: The conversation of this CampaignInteraction.
        :rtype: Conversation
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """
        Sets the conversation of this CampaignInteraction.


        :param conversation: The conversation of this CampaignInteraction.
        :type: Conversation
        """
        
        self._conversation = conversation

    @property
    def dialer_system_participant_id(self):
        """
        Gets the dialer_system_participant_id of this CampaignInteraction.
        conversation participant id that is the dialer system participant to monitor the call from dialer perspective

        :return: The dialer_system_participant_id of this CampaignInteraction.
        :rtype: str
        """
        return self._dialer_system_participant_id

    @dialer_system_participant_id.setter
    def dialer_system_participant_id(self, dialer_system_participant_id):
        """
        Sets the dialer_system_participant_id of this CampaignInteraction.
        conversation participant id that is the dialer system participant to monitor the call from dialer perspective

        :param dialer_system_participant_id: The dialer_system_participant_id of this CampaignInteraction.
        :type: str
        """
        
        self._dialer_system_participant_id = dialer_system_participant_id

    @property
    def dialing_mode(self):
        """
        Gets the dialing_mode of this CampaignInteraction.


        :return: The dialing_mode of this CampaignInteraction.
        :rtype: str
        """
        return self._dialing_mode

    @dialing_mode.setter
    def dialing_mode(self, dialing_mode):
        """
        Sets the dialing_mode of this CampaignInteraction.


        :param dialing_mode: The dialing_mode of this CampaignInteraction.
        :type: str
        """
        
        self._dialing_mode = dialing_mode

    @property
    def skills(self):
        """
        Gets the skills of this CampaignInteraction.
        Any skills that are attached to the call for routing

        :return: The skills of this CampaignInteraction.
        :rtype: list[UriReference]
        """
        return self._skills

    @skills.setter
    def skills(self, skills):
        """
        Sets the skills of this CampaignInteraction.
        Any skills that are attached to the call for routing

        :param skills: The skills of this CampaignInteraction.
        :type: list[UriReference]
        """
        
        self._skills = skills

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class VideoConversationNotificationVideoMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VideoConversationNotificationVideoMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'CallbackConversationNotificationUser',
            'queue': 'VideoConversationNotificationUriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'VideoConversationNotificationErrorInfo',
            'script': 'VideoConversationNotificationUriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'provider': 'str',
            'external_contact': 'VideoConversationNotificationUriReference',
            'external_organization': 'VideoConversationNotificationUriReference',
            'audio_muted': 'bool',
            'video_muted': 'bool',
            'sharing_screen': 'bool',
            'peer_count': 'int',
            'context': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'provider': 'provider',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'audio_muted': 'audioMuted',
            'video_muted': 'videoMuted',
            'sharing_screen': 'sharingScreen',
            'peer_count': 'peerCount',
            'context': 'context'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = None
        self._wrapup_required = None
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = None
        self._provider = None
        self._external_contact = None
        self._external_organization = None
        self._audio_muted = None
        self._video_muted = None
        self._sharing_screen = None
        self._peer_count = None
        self._context = None

    @property
    def id(self):
        """
        Gets the id of this VideoConversationNotificationVideoMediaParticipant.


        :return: The id of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VideoConversationNotificationVideoMediaParticipant.


        :param id: The id of this VideoConversationNotificationVideoMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this VideoConversationNotificationVideoMediaParticipant.


        :return: The name of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this VideoConversationNotificationVideoMediaParticipant.


        :param name: The name of this VideoConversationNotificationVideoMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this VideoConversationNotificationVideoMediaParticipant.


        :return: The address of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this VideoConversationNotificationVideoMediaParticipant.


        :param address: The address of this VideoConversationNotificationVideoMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this VideoConversationNotificationVideoMediaParticipant.


        :return: The start_time of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this VideoConversationNotificationVideoMediaParticipant.


        :param start_time: The start_time of this VideoConversationNotificationVideoMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this VideoConversationNotificationVideoMediaParticipant.


        :return: The connected_time of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this VideoConversationNotificationVideoMediaParticipant.


        :param connected_time: The connected_time of this VideoConversationNotificationVideoMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this VideoConversationNotificationVideoMediaParticipant.


        :return: The end_time of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this VideoConversationNotificationVideoMediaParticipant.


        :param end_time: The end_time of this VideoConversationNotificationVideoMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this VideoConversationNotificationVideoMediaParticipant.


        :return: The start_hold_time of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this VideoConversationNotificationVideoMediaParticipant.


        :param start_hold_time: The start_hold_time of this VideoConversationNotificationVideoMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this VideoConversationNotificationVideoMediaParticipant.


        :return: The purpose of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this VideoConversationNotificationVideoMediaParticipant.


        :param purpose: The purpose of this VideoConversationNotificationVideoMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this VideoConversationNotificationVideoMediaParticipant.


        :return: The state of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this VideoConversationNotificationVideoMediaParticipant.


        :param state: The state of this VideoConversationNotificationVideoMediaParticipant.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "scheduled", "none"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this VideoConversationNotificationVideoMediaParticipant.


        :return: The direction of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this VideoConversationNotificationVideoMediaParticipant.


        :param direction: The direction of this VideoConversationNotificationVideoMediaParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction not in allowed_values:
            raise ValueError(
                "Invalid value for `direction`, must be one of {0}"
                .format(allowed_values)
            )

        self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this VideoConversationNotificationVideoMediaParticipant.


        :return: The disconnect_type of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this VideoConversationNotificationVideoMediaParticipant.


        :param disconnect_type: The disconnect_type of this VideoConversationNotificationVideoMediaParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "timeout", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this VideoConversationNotificationVideoMediaParticipant.


        :return: The held of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this VideoConversationNotificationVideoMediaParticipant.


        :param held: The held of this VideoConversationNotificationVideoMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this VideoConversationNotificationVideoMediaParticipant.


        :return: The wrapup_required of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this VideoConversationNotificationVideoMediaParticipant.


        :param wrapup_required: The wrapup_required of this VideoConversationNotificationVideoMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this VideoConversationNotificationVideoMediaParticipant.


        :return: The wrapup_prompt of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this VideoConversationNotificationVideoMediaParticipant.


        :param wrapup_prompt: The wrapup_prompt of this VideoConversationNotificationVideoMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this VideoConversationNotificationVideoMediaParticipant.


        :return: The user of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: CallbackConversationNotificationUser
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this VideoConversationNotificationVideoMediaParticipant.


        :param user: The user of this VideoConversationNotificationVideoMediaParticipant.
        :type: CallbackConversationNotificationUser
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this VideoConversationNotificationVideoMediaParticipant.


        :return: The queue of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: VideoConversationNotificationUriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this VideoConversationNotificationVideoMediaParticipant.


        :param queue: The queue of this VideoConversationNotificationVideoMediaParticipant.
        :type: VideoConversationNotificationUriReference
        """
        
        self._queue = queue

    @property
    def attributes(self):
        """
        Gets the attributes of this VideoConversationNotificationVideoMediaParticipant.


        :return: The attributes of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this VideoConversationNotificationVideoMediaParticipant.


        :param attributes: The attributes of this VideoConversationNotificationVideoMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this VideoConversationNotificationVideoMediaParticipant.


        :return: The error_info of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: VideoConversationNotificationErrorInfo
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this VideoConversationNotificationVideoMediaParticipant.


        :param error_info: The error_info of this VideoConversationNotificationVideoMediaParticipant.
        :type: VideoConversationNotificationErrorInfo
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this VideoConversationNotificationVideoMediaParticipant.


        :return: The script of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: VideoConversationNotificationUriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this VideoConversationNotificationVideoMediaParticipant.


        :param script: The script of this VideoConversationNotificationVideoMediaParticipant.
        :type: VideoConversationNotificationUriReference
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this VideoConversationNotificationVideoMediaParticipant.


        :return: The wrapup_timeout_ms of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this VideoConversationNotificationVideoMediaParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this VideoConversationNotificationVideoMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this VideoConversationNotificationVideoMediaParticipant.


        :return: The wrapup_skipped of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this VideoConversationNotificationVideoMediaParticipant.


        :param wrapup_skipped: The wrapup_skipped of this VideoConversationNotificationVideoMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def provider(self):
        """
        Gets the provider of this VideoConversationNotificationVideoMediaParticipant.


        :return: The provider of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this VideoConversationNotificationVideoMediaParticipant.


        :param provider: The provider of this VideoConversationNotificationVideoMediaParticipant.
        :type: str
        """
        
        self._provider = provider

    @property
    def external_contact(self):
        """
        Gets the external_contact of this VideoConversationNotificationVideoMediaParticipant.


        :return: The external_contact of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: VideoConversationNotificationUriReference
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this VideoConversationNotificationVideoMediaParticipant.


        :param external_contact: The external_contact of this VideoConversationNotificationVideoMediaParticipant.
        :type: VideoConversationNotificationUriReference
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this VideoConversationNotificationVideoMediaParticipant.


        :return: The external_organization of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: VideoConversationNotificationUriReference
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this VideoConversationNotificationVideoMediaParticipant.


        :param external_organization: The external_organization of this VideoConversationNotificationVideoMediaParticipant.
        :type: VideoConversationNotificationUriReference
        """
        
        self._external_organization = external_organization

    @property
    def audio_muted(self):
        """
        Gets the audio_muted of this VideoConversationNotificationVideoMediaParticipant.


        :return: The audio_muted of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: bool
        """
        return self._audio_muted

    @audio_muted.setter
    def audio_muted(self, audio_muted):
        """
        Sets the audio_muted of this VideoConversationNotificationVideoMediaParticipant.


        :param audio_muted: The audio_muted of this VideoConversationNotificationVideoMediaParticipant.
        :type: bool
        """
        
        self._audio_muted = audio_muted

    @property
    def video_muted(self):
        """
        Gets the video_muted of this VideoConversationNotificationVideoMediaParticipant.


        :return: The video_muted of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: bool
        """
        return self._video_muted

    @video_muted.setter
    def video_muted(self, video_muted):
        """
        Sets the video_muted of this VideoConversationNotificationVideoMediaParticipant.


        :param video_muted: The video_muted of this VideoConversationNotificationVideoMediaParticipant.
        :type: bool
        """
        
        self._video_muted = video_muted

    @property
    def sharing_screen(self):
        """
        Gets the sharing_screen of this VideoConversationNotificationVideoMediaParticipant.


        :return: The sharing_screen of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: bool
        """
        return self._sharing_screen

    @sharing_screen.setter
    def sharing_screen(self, sharing_screen):
        """
        Sets the sharing_screen of this VideoConversationNotificationVideoMediaParticipant.


        :param sharing_screen: The sharing_screen of this VideoConversationNotificationVideoMediaParticipant.
        :type: bool
        """
        
        self._sharing_screen = sharing_screen

    @property
    def peer_count(self):
        """
        Gets the peer_count of this VideoConversationNotificationVideoMediaParticipant.


        :return: The peer_count of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: int
        """
        return self._peer_count

    @peer_count.setter
    def peer_count(self, peer_count):
        """
        Sets the peer_count of this VideoConversationNotificationVideoMediaParticipant.


        :param peer_count: The peer_count of this VideoConversationNotificationVideoMediaParticipant.
        :type: int
        """
        
        self._peer_count = peer_count

    @property
    def context(self):
        """
        Gets the context of this VideoConversationNotificationVideoMediaParticipant.


        :return: The context of this VideoConversationNotificationVideoMediaParticipant.
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the context of this VideoConversationNotificationVideoMediaParticipant.


        :param context: The context of this VideoConversationNotificationVideoMediaParticipant.
        :type: str
        """
        
        self._context = context

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ForecastMetadata(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ForecastMetadata - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'number_of_periods': 'int',
            'period_frequency': 'str',
            'description': 'str',
            'metrics': 'list[str]',
            'last_modified_date': 'datetime',
            'last_modified_by': 'User',
            'status': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'number_of_periods': 'numberOfPeriods',
            'period_frequency': 'periodFrequency',
            'description': 'description',
            'metrics': 'metrics',
            'last_modified_date': 'lastModifiedDate',
            'last_modified_by': 'lastModifiedBy',
            'status': 'status',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._number_of_periods = None
        self._period_frequency = None
        self._description = None
        self._metrics = None
        self._last_modified_date = None
        self._last_modified_by = None
        self._status = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ForecastMetadata.
        The globally unique identifier for the object.

        :return: The id of this ForecastMetadata.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ForecastMetadata.
        The globally unique identifier for the object.

        :param id: The id of this ForecastMetadata.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ForecastMetadata.


        :return: The name of this ForecastMetadata.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ForecastMetadata.


        :param name: The name of this ForecastMetadata.
        :type: str
        """
        
        self._name = name

    @property
    def number_of_periods(self):
        """
        Gets the number_of_periods of this ForecastMetadata.
        The number of periods to be forecasted for

        :return: The number_of_periods of this ForecastMetadata.
        :rtype: int
        """
        return self._number_of_periods

    @number_of_periods.setter
    def number_of_periods(self, number_of_periods):
        """
        Sets the number_of_periods of this ForecastMetadata.
        The number of periods to be forecasted for

        :param number_of_periods: The number_of_periods of this ForecastMetadata.
        :type: int
        """
        
        self._number_of_periods = number_of_periods

    @property
    def period_frequency(self):
        """
        Gets the period_frequency of this ForecastMetadata.
        The frequency of the period

        :return: The period_frequency of this ForecastMetadata.
        :rtype: str
        """
        return self._period_frequency

    @period_frequency.setter
    def period_frequency(self, period_frequency):
        """
        Sets the period_frequency of this ForecastMetadata.
        The frequency of the period

        :param period_frequency: The period_frequency of this ForecastMetadata.
        :type: str
        """
        allowed_values = ["WEEK"]
        if period_frequency not in allowed_values:
            raise ValueError(
                "Invalid value for `period_frequency`, must be one of {0}"
                .format(allowed_values)
            )

        self._period_frequency = period_frequency

    @property
    def description(self):
        """
        Gets the description of this ForecastMetadata.
        The description of the forecast to be created

        :return: The description of this ForecastMetadata.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ForecastMetadata.
        The description of the forecast to be created

        :param description: The description of this ForecastMetadata.
        :type: str
        """
        
        self._description = description

    @property
    def metrics(self):
        """
        Gets the metrics of this ForecastMetadata.
        The metrics the forecast is for

        :return: The metrics of this ForecastMetadata.
        :rtype: list[str]
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """
        Sets the metrics of this ForecastMetadata.
        The metrics the forecast is for

        :param metrics: The metrics of this ForecastMetadata.
        :type: list[str]
        """
        
        self._metrics = metrics

    @property
    def last_modified_date(self):
        """
        Gets the last_modified_date of this ForecastMetadata.
        The last modified date time of this object. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The last_modified_date of this ForecastMetadata.
        :rtype: datetime
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """
        Sets the last_modified_date of this ForecastMetadata.
        The last modified date time of this object. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param last_modified_date: The last_modified_date of this ForecastMetadata.
        :type: datetime
        """
        
        self._last_modified_date = last_modified_date

    @property
    def last_modified_by(self):
        """
        Gets the last_modified_by of this ForecastMetadata.
        The person who last modified this object

        :return: The last_modified_by of this ForecastMetadata.
        :rtype: User
        """
        return self._last_modified_by

    @last_modified_by.setter
    def last_modified_by(self, last_modified_by):
        """
        Sets the last_modified_by of this ForecastMetadata.
        The person who last modified this object

        :param last_modified_by: The last_modified_by of this ForecastMetadata.
        :type: User
        """
        
        self._last_modified_by = last_modified_by

    @property
    def status(self):
        """
        Gets the status of this ForecastMetadata.
        The status of the creation of the forecast

        :return: The status of this ForecastMetadata.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ForecastMetadata.
        The status of the creation of the forecast

        :param status: The status of this ForecastMetadata.
        :type: str
        """
        allowed_values = ["SUCCESS", "FAILED"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status`, must be one of {0}"
                .format(allowed_values)
            )

        self._status = status

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ForecastMetadata.
        The URI for this object

        :return: The self_uri of this ForecastMetadata.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ForecastMetadata.
        The URI for this object

        :param self_uri: The self_uri of this ForecastMetadata.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ConversationNotificationCalls(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ConversationNotificationCalls - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'state': 'str',
            'recording': 'bool',
            'recording_state': 'str',
            'muted': 'bool',
            'confined': 'bool',
            'held': 'bool',
            'error_info': 'ConversationNotificationErrorInfo',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'direction': 'str',
            'document_id': 'str',
            'pcSelf': 'ConversationNotificationSelf',
            'other': 'ConversationNotificationAddress',
            'provider': 'str',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'disconnect_reasons': 'list[ConversationNotificationDisconnectReasons]',
            'fax_status': 'ConversationNotificationFaxStatus',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'state': 'state',
            'recording': 'recording',
            'recording_state': 'recordingState',
            'muted': 'muted',
            'confined': 'confined',
            'held': 'held',
            'error_info': 'errorInfo',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'direction': 'direction',
            'document_id': 'documentId',
            'pcSelf': 'self',
            'other': 'other',
            'provider': 'provider',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'disconnect_reasons': 'disconnectReasons',
            'fax_status': 'faxStatus',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._state = None
        self._recording = None
        self._recording_state = None
        self._muted = None
        self._confined = None
        self._held = None
        self._error_info = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._direction = None
        self._document_id = None
        self._pcSelf = None
        self._other = None
        self._provider = None
        self._connected_time = None
        self._disconnected_time = None
        self._disconnect_reasons = None
        self._fax_status = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this ConversationNotificationCalls.


        :return: The id of this ConversationNotificationCalls.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConversationNotificationCalls.


        :param id: The id of this ConversationNotificationCalls.
        :type: str
        """
        
        self._id = id

    @property
    def state(self):
        """
        Gets the state of this ConversationNotificationCalls.


        :return: The state of this ConversationNotificationCalls.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ConversationNotificationCalls.


        :param state: The state of this ConversationNotificationCalls.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "UPLOADING", "CONVERTING", "TRANSMITTING", "NONE"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def recording(self):
        """
        Gets the recording of this ConversationNotificationCalls.


        :return: The recording of this ConversationNotificationCalls.
        :rtype: bool
        """
        return self._recording

    @recording.setter
    def recording(self, recording):
        """
        Sets the recording of this ConversationNotificationCalls.


        :param recording: The recording of this ConversationNotificationCalls.
        :type: bool
        """
        
        self._recording = recording

    @property
    def recording_state(self):
        """
        Gets the recording_state of this ConversationNotificationCalls.


        :return: The recording_state of this ConversationNotificationCalls.
        :rtype: str
        """
        return self._recording_state

    @recording_state.setter
    def recording_state(self, recording_state):
        """
        Sets the recording_state of this ConversationNotificationCalls.


        :param recording_state: The recording_state of this ConversationNotificationCalls.
        :type: str
        """
        allowed_values = ["NONE", "ACTIVE", "PAUSED"]
        if recording_state not in allowed_values:
            raise ValueError(
                "Invalid value for `recording_state`, must be one of {0}"
                .format(allowed_values)
            )

        self._recording_state = recording_state

    @property
    def muted(self):
        """
        Gets the muted of this ConversationNotificationCalls.


        :return: The muted of this ConversationNotificationCalls.
        :rtype: bool
        """
        return self._muted

    @muted.setter
    def muted(self, muted):
        """
        Sets the muted of this ConversationNotificationCalls.


        :param muted: The muted of this ConversationNotificationCalls.
        :type: bool
        """
        
        self._muted = muted

    @property
    def confined(self):
        """
        Gets the confined of this ConversationNotificationCalls.


        :return: The confined of this ConversationNotificationCalls.
        :rtype: bool
        """
        return self._confined

    @confined.setter
    def confined(self, confined):
        """
        Sets the confined of this ConversationNotificationCalls.


        :param confined: The confined of this ConversationNotificationCalls.
        :type: bool
        """
        
        self._confined = confined

    @property
    def held(self):
        """
        Gets the held of this ConversationNotificationCalls.


        :return: The held of this ConversationNotificationCalls.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this ConversationNotificationCalls.


        :param held: The held of this ConversationNotificationCalls.
        :type: bool
        """
        
        self._held = held

    @property
    def error_info(self):
        """
        Gets the error_info of this ConversationNotificationCalls.


        :return: The error_info of this ConversationNotificationCalls.
        :rtype: ConversationNotificationErrorInfo
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this ConversationNotificationCalls.


        :param error_info: The error_info of this ConversationNotificationCalls.
        :type: ConversationNotificationErrorInfo
        """
        
        self._error_info = error_info

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this ConversationNotificationCalls.


        :return: The disconnect_type of this ConversationNotificationCalls.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this ConversationNotificationCalls.


        :param disconnect_type: The disconnect_type of this ConversationNotificationCalls.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this ConversationNotificationCalls.


        :return: The start_hold_time of this ConversationNotificationCalls.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this ConversationNotificationCalls.


        :param start_hold_time: The start_hold_time of this ConversationNotificationCalls.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def direction(self):
        """
        Gets the direction of this ConversationNotificationCalls.


        :return: The direction of this ConversationNotificationCalls.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this ConversationNotificationCalls.


        :param direction: The direction of this ConversationNotificationCalls.
        :type: str
        """
        allowed_values = ["OUTBOUND", "INBOUND"]
        if direction not in allowed_values:
            raise ValueError(
                "Invalid value for `direction`, must be one of {0}"
                .format(allowed_values)
            )

        self._direction = direction

    @property
    def document_id(self):
        """
        Gets the document_id of this ConversationNotificationCalls.


        :return: The document_id of this ConversationNotificationCalls.
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """
        Sets the document_id of this ConversationNotificationCalls.


        :param document_id: The document_id of this ConversationNotificationCalls.
        :type: str
        """
        
        self._document_id = document_id

    @property
    def pcSelf(self):
        """
        Gets the pcSelf of this ConversationNotificationCalls.


        :return: The pcSelf of this ConversationNotificationCalls.
        :rtype: ConversationNotificationSelf
        """
        return self._pcSelf

    @pcSelf.setter
    def pcSelf(self, pcSelf):
        """
        Sets the pcSelf of this ConversationNotificationCalls.


        :param pcSelf: The pcSelf of this ConversationNotificationCalls.
        :type: ConversationNotificationSelf
        """
        
        self._pcSelf = pcSelf

    @property
    def other(self):
        """
        Gets the other of this ConversationNotificationCalls.


        :return: The other of this ConversationNotificationCalls.
        :rtype: ConversationNotificationAddress
        """
        return self._other

    @other.setter
    def other(self, other):
        """
        Sets the other of this ConversationNotificationCalls.


        :param other: The other of this ConversationNotificationCalls.
        :type: ConversationNotificationAddress
        """
        
        self._other = other

    @property
    def provider(self):
        """
        Gets the provider of this ConversationNotificationCalls.


        :return: The provider of this ConversationNotificationCalls.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this ConversationNotificationCalls.


        :param provider: The provider of this ConversationNotificationCalls.
        :type: str
        """
        
        self._provider = provider

    @property
    def connected_time(self):
        """
        Gets the connected_time of this ConversationNotificationCalls.


        :return: The connected_time of this ConversationNotificationCalls.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this ConversationNotificationCalls.


        :param connected_time: The connected_time of this ConversationNotificationCalls.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this ConversationNotificationCalls.


        :return: The disconnected_time of this ConversationNotificationCalls.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this ConversationNotificationCalls.


        :param disconnected_time: The disconnected_time of this ConversationNotificationCalls.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def disconnect_reasons(self):
        """
        Gets the disconnect_reasons of this ConversationNotificationCalls.


        :return: The disconnect_reasons of this ConversationNotificationCalls.
        :rtype: list[ConversationNotificationDisconnectReasons]
        """
        return self._disconnect_reasons

    @disconnect_reasons.setter
    def disconnect_reasons(self, disconnect_reasons):
        """
        Sets the disconnect_reasons of this ConversationNotificationCalls.


        :param disconnect_reasons: The disconnect_reasons of this ConversationNotificationCalls.
        :type: list[ConversationNotificationDisconnectReasons]
        """
        
        self._disconnect_reasons = disconnect_reasons

    @property
    def fax_status(self):
        """
        Gets the fax_status of this ConversationNotificationCalls.


        :return: The fax_status of this ConversationNotificationCalls.
        :rtype: ConversationNotificationFaxStatus
        """
        return self._fax_status

    @fax_status.setter
    def fax_status(self, fax_status):
        """
        Sets the fax_status of this ConversationNotificationCalls.


        :param fax_status: The fax_status of this ConversationNotificationCalls.
        :type: ConversationNotificationFaxStatus
        """
        
        self._fax_status = fax_status

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this ConversationNotificationCalls.


        :return: The additional_properties of this ConversationNotificationCalls.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this ConversationNotificationCalls.


        :param additional_properties: The additional_properties of this ConversationNotificationCalls.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

